@@ -9,7 +9,8 @@ import pygame
 
 def main():
 
-    pygame.image.load("./snake6.png")
+    print(os.path.abspath(__file__))
+    # pygame.image.load("./snake6.png")
 
     # January = February = March = April = May = June = July = August = September = October = November = December = []
     # year = [January, February, March, April, May, June, July, August, September, October, November, December]
